# UserWithRankModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**first_name** | **str, none_type** |  | [optional] 
**last_name** | **str, none_type** |  | [optional] 
**middle_name** | **str, none_type** |  | [optional] 
**user_name** | **str, none_type** |  | [optional] 
**display_name** | **str, none_type** |  | [optional] 
**user_type** | **str, none_type** |  | [optional] 
**avatar_url** | **str, none_type** |  | [optional] 
**avatar_metadata** | **str, none_type** |  | [optional] 
**is_deleted** | **bool** |  | [optional] 
**is_disabled** | **bool** |  | [optional] 
**provider_id** | **str, none_type** |  | [optional] 
**is_active_status_by_entity** | **bool** |  | [optional] 
**user_rank** | [**UserRankModel**](UserRankModel.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


